Documentation
¶
Index ¶
- Constants
- func CreateFileIfNotExists(filePath string) error
- func CustomRelTime(a, b time.Time, albl, blbl string, magnitudes []RelTimeMagnitude) string
- func FileExists(filePath string) (bool, error)
- func FilterStringId(stringIds string, filterId int) string
- func FriendlyTime(t time.Time) string
- func GetFilenamePath(prefix string) string
- func GetRandomNickname() string
- func GetRandomString(n int) string
- func HidePhoneNumber(phoneNumber string) string
- func IdCompare(ids1, ids2 []uint) (change []uint, increase []uint, decrease []uint)
- func IntSliceToString[T Integer](nums ...T) string
- func LimitString(str string, limit int) string
- func PathExists(path string) (bool, error)
- func RelTime(a, b time.Time, albl, blbl string) string
- func SliceFindIndex[T comparable](inputSlice []T, a T) int
- func String2Slice(s string) []string
- func StringToSlice[T Integer](str string) []T
- func StructToMap(input any) map[string]any
- func Time(then time.Time) string
- func TodayStartAndEndTime() (beginTime, endTime uint)
- func UintsToString(numbers ...uint) string
- func UniqueSlice[T comparable](inputSlice []T) []T
- func Unzip(src, dest string) ([]string, error)
- type Integer
- type JsonMap
- type RelTimeMagnitude
Constants ¶
const ( Day = 24 * time.Hour Week = 7 * Day Month = 30 * Day Year = 12 * Month LongTime = 37 * Year )
Seconds-based time units
Variables ¶
This section is empty.
Functions ¶
func CreateFileIfNotExists ¶
func CustomRelTime ¶
func CustomRelTime(a, b time.Time, albl, blbl string, magnitudes []RelTimeMagnitude) string
CustomRelTime formats a time into a relative string.
It takes two times two labels and a table of relative time formats. In addition to the generic time delta string (e.g. 5 minutes), the labels are used applied so that the label corresponding to the smaller time is applied.
func FileExists ¶
func FilterStringId ¶
func FriendlyTime ¶
func GetFilenamePath ¶
func GetRandomNickname ¶
func GetRandomNickname() string
func GetRandomString ¶
func HidePhoneNumber ¶
func IntSliceToString ¶
func LimitString ¶
func RelTime ¶
RelTime formats a time into a relative string.
It takes two times and two labels. In addition to the generic time delta string (e.g. 5 minutes), the labels are used applied so that the label corresponding to the smaller time is applied.
RelTime(timeInPast, timeInFuture, "earlier", "later") -> "3 weeks earlier"
func SliceFindIndex ¶
func SliceFindIndex[T comparable](inputSlice []T, a T) int
func String2Slice ¶
func StringToSlice ¶ added in v1.1.0
StringToSlice 将字符串转换为去重后的整数切片。
func StructToMap ¶
func TodayStartAndEndTime ¶
func TodayStartAndEndTime() (beginTime, endTime uint)
func UintsToString ¶
func UniqueSlice ¶
func UniqueSlice[T comparable](inputSlice []T) []T
Types ¶
type JsonMap ¶
type JsonMap struct {
}
func (*JsonMap) MarshalBinary ¶
func (*JsonMap) UnmarshalBinary ¶
type RelTimeMagnitude ¶
A RelTimeMagnitude struct contains a relative time point at which the relative format of time will switch to a new format string. A slice of these in ascending order by their "D" field is passed to CustomRelTime to format durations.
The Format field is a string that may contain a "%s" which will be replaced with the appropriate signed label (e.g. "ago" or "from now") and a "%d" that will be replaced by the quantity.
The DivBy field is the amount of time the time difference must be divided by in order to display correctly.
e.g. if D is 2*time.Minute and you want to display "%d minutes %s" DivBy should be time.Minute so whatever the duration is will be expressed in minutes.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package bytefmt contains helper methods and constants for converting to and from a human-readable byte format.
|
Package bytefmt contains helper methods and constants for converting to and from a human-readable byte format. |